/*********************************************************************
 *
 *      Hardware specific definitions
 *
 *********************************************************************
 * FileName:        HardwareProfile.h
 * Dependencies:    None
 * Processor:       PIC18, PIC24F, PIC24H, dsPIC30F, dsPIC33F, PIC32
 * Compiler:        Microchip C32 v1.05 or higher
 *                                      Microchip C30 v3.12 or higher
 *                                      Microchip C18 v3.30 or higher
 *                                      HI-TECH PICC-18 PRO 9.63PL2 or higher
******************************************************************************/


#ifndef __HARDWARE_PROFILE_H
#define __HARDWARE_PROFILE_H


#define SaveAppConfig()
#define USE_LCD
#include "GenericTypeDefs.h"
#include "Compiler.h"




// Set configuration fuses (but only once)
#if defined(THIS_IS_STACK_APPLICATION)
        #if defined(__18CXX)
                #if defined(__EXTENDED18__)
                        #pragma config XINST=ON
                #elif !defined(HI_TECH_C)
                        #pragma config XINST=OFF
                #endif
        #endif
        
#endif

        //#pragma config OSC=HSPLL, WDT=OFF, MCLRE=ON, PBADEN=OFF, LVP=OFF

        


        #define GetSystemClock()                (32000000ul)      // Hz
        #define GetInstructionClock()   (GetSystemClock()/4)
        #define GetPeripheralClock()    GetInstructionClock()


		#define LED0_TRIS			(TRISAbits.TRISA1)
		#define LED0_IO				(LATAbits.LATA1)
		#define LED1_TRIS			(TRISDbits.TRISD1)
		#define LED1_IO				(LATDbits.LATD1)
		#define LED2_TRIS			(TRISDbits.TRISD2)
		#define LED2_IO				(LATDbits.LATD2)
		#define LED3_TRIS			(TRISDbits.TRISD3)
		#define LED3_IO				(LATDbits.LATD3)
		#define LED4_TRIS			(TRISDbits.TRISD4)
		#define LED4_IO				(LATDbits.LATD4)
		#define LED5_TRIS			(TRISDbits.TRISD5)
		#define LED5_IO				(LATDbits.LATD5)
		#define LED6_TRIS			(TRISDbits.TRISD6)
		#define LED6_IO				(LATDbits.LATD6)
		#define LED7_TRIS			(TRISDbits.TRISD7)
//		#define LED7_IO				(LATDbits.LATD7)
		#define LED_GET()			(LATD)
		#define LED_PUT(a)			(LATD = (a))


        #define BUTTON0_TRIS            (TRISAbits.TRISA0)
        #define BUTTON0_IO              (PORTAbits.RA0)



        // ENC28J60 I/O pins
        #define ENC_RST_TRIS            (TRISCbits.TRISC7)
        #define ENC_RST_IO              (LATCbits.LATC7)
        #define ENC_CS_TRIS             (TRISCbits.TRISC6)      // Uncomment this line to use the ENC28J60 Ethernet controller or comment it out to use some other network controller
        #define ENC_CS_IO               (LATCbits.LATC6)
        #define ENC_SCK_TRIS            (TRISCbits.TRISC3)
        #define ENC_SDI_TRIS            (TRISCbits.TRISC4)
        #define ENC_SDO_TRIS            (TRISCbits.TRISC5)
        #define ENC_SPI_IF              (PIR1bits.SSPIF)
        #define ENC_SSPBUF              (SSPBUF)
        #define ENC_SPISTAT             (SSPSTAT)
        #define ENC_SPISTATbits         (SSPSTATbits)
        #define ENC_SPICON1             (SSPCON1)
        #define ENC_SPICON1bits         (SSPCON1bits)

		
		// LCD Module I/O pins
	#define LCD_DATA0_TRIS		(TRISBbits.TRISB4)		// Multiplexed with LED6
	#define LCD_DATA0_IO		(LATBbits.LATB4)
	#define LCD_DATA1_TRIS		(TRISBbits.TRISB5)
	#define LCD_DATA1_IO		(LATBbits.LATB5)
	#define LCD_DATA2_TRIS		(TRISBbits.TRISB6)
	#define LCD_DATA2_IO		(LATBbits.LATB6)
	#define LCD_DATA3_TRIS		(TRISBbits.TRISB7)		// Multiplexed with LED3
	#define LCD_DATA3_IO		(LATBbits.LATB7)
//	#define LCD_DATA4_TRIS		(TRISBbits.TRISB8)		// Multiplexed with LED2
//	#define LCD_DATA4_IO		(LATBbits.LATB8)
//	#define LCD_DATA5_TRIS		(TRISBbits.TRISB7)
//	#define LCD_DATA5_IO		(LATBbits.LATB7)
//	#define LCD_DATA6_TRIS		(TRISBbits.TRISB6)
//	#define LCD_DATA6_IO		(LATBbits.LATB6)
//	#define LCD_DATA7_TRIS		(TRISBbits.TRISB5)
//	#define LCD_DATA7_IO		(LATBbits.LATB5)
//	#define LCD_RD_WR_TRIS		(TRISBbits.TRISB13)
//	#define LCD_RD_WR_IO		(LATBbits.LATB13)
	#define LCD_RS_TRIS			(TRISBbits.TRISB0)
	#define LCD_RS_IO			(LATBbits.LATB0)
	#define LCD_E_TRIS			(TRISBbits.TRISB1)
	#define LCD_E_IO			(LATBbits.LATB1)

#endif

