/*********************************************************************
 *
 *  Main Application Entry Point and TCP/IP Stack Demo
 *  Module for Microchip TCP/IP Stack
 *   -Demonstrates how to call and use the Microchip TCP/IP stack
 *	 -Reference: AN833
 *
 *********************************************************************
 * FileName:        MainDemo.c
 * Dependencies:    TCPIP.h
 * Processor:       PIC18, PIC24F, PIC24H, dsPIC30F, dsPIC33F, PIC32
 * Compiler:        Microchip C32 v1.05 or higher
 *					Microchip C30 v3.12 or higher
 *					Microchip C18 v3.30 or higher
 *					HI-TECH PICC-18 PRO 9.63PL2 or higher
 ********************************************************************/

#include "TCPIP.h"

#pragma config OSC = HS/*INTIO67*/,FCMEN = OFF,IESO = OFF 
#pragma config BOREN = OFF,WDT = OFF,MCLRE = ON
#pragma config PBADEN = OFF,STVREN = OFF,LVP = OFF
#pragma config XINST = OFF,DEBUG = OFF
/*
 * This macro uniquely defines this file as the main entry point.
 //* There should only be one such definition in the entire project,
 //* and this file must define the AppConfig variable as described below.
// */
#define THIS_IS_STACK_APPLICATION


// Include functions specific to this stack application
#include "MainDemo.h"

// Declare AppConfig structure and some other supporting stack variables
APP_CONFIG AppConfig;
//BYTE AN0String[8];
//BYTE myDHCPBindCount = 0xFF;





// Private helper functions.
// These may or may not be present in all applications.
static void InitAppConfig(void);
static void InitializeBoard(void);
//static void ProcessIO(void);
//void DelayFor18TCY( void );
//void DelayPORXLCD (void);
//void DelayXLCD (void);

//
// PIC18 Interrupt Service Routines
// 
// NOTE: Several PICs, including the PIC18F4620 revision A3 have a RETFIE FAST/MOVFF bug
// The interruptlow keyword is used to work around the bug when using C18
#if defined(__18CXX)
	#if defined(HI_TECH_C)
		void interrupt low_priority LowISR(void)
	#else
		#pragma interruptlow LowISR
		void LowISR(void)
	#endif
	{
	    TickUpdate();
	}
	
	#if defined(HI_TECH_C)
		void interrupt HighISR(void)
	#else
		#pragma interruptlow HighISR
		void HighISR(void)
	#endif
	{
	    #if defined(STACK_USE_UART2TCP_BRIDGE)
			UART2TCPBridgeISR();
		#endif

		#if defined(ZG_CS_TRIS)
			zgEintISR();
		#endif // ZG_CS_TRIS
	}

	#if !defined(HI_TECH_C)
		#pragma code lowVector=0x18
		void LowVector(void){_asm goto LowISR _endasm}
		#pragma code highVector=0x8
		void HighVector(void){_asm goto HighISR _endasm}
		#pragma code // Return to default code section
	#endif

//#endif

//
// Main application entry point.
//
void main(void)
{
    static TICK t = 0;

    // Initialize application specific hardware
    InitializeBoard();

//	#if defined(USE_LCD)
//	// Initialize and display the stack version on the LCD
//	LCDInit();
//	DelayMs(100);
//	strcpypgm2ram((char*)LCDText, "TCPStack " VERSION "  "
//		"                ");
//	LCDUpdate();
//	#endif

	// Initialize stack-related hardware components that may be 
	// required by the UART configuration routines
    TickInit();

	// Initialize Stack and application related NV variables into AppConfig.
	InitAppConfig();

    
//    if(BUTTON0_IO == 0u)
//
//	// Initialize core stack layers (MAC, ARP, TCP, UDP) and
//	// application modules (HTTP, SNMP, etc.)
    StackInit();
//
	
//
    while(1)
    {
        // Blink LED0 (right most one) every second.
        if(TickGet() - t >= TICK_SECOND/2ul)
        {
            t = TickGet();
           LED0_IO ^= 1;
        }
//
//        // This task performs normal stack task including checking
//        // for incoming packet, type of packet and calling
//        // appropriate stack entity to process it.
//        StackTask();
//        
//        // This tasks invokes each of the core stack application tasks
//        StackApplications();
	   StackTask();	
	   PingDemo();

        

	}
}

// Writes an IP address to the LCD display and the UART as available
//void DisplayIPValue(IP_ADDR IPVal)
//{
////	printf("%u.%u.%u.%u", IPVal.v[0], IPVal.v[1], IPVal.v[2], IPVal.v[3]);
//    BYTE IPDigit[4];
//	BYTE i;
//#ifdef USE_LCD
//	BYTE j;
//	BYTE LCDPos=16;
//#endif
//
//	for(i = 0; i < sizeof(IP_ADDR); i++)
//	{
//	    uitoa((WORD)IPVal.v[i], IPDigit);
//
//
//		#ifdef USE_LCD
//			for(j = 0; j < strlen((char*)IPDigit); j++)
//			{
//				LCDText[LCDPos++] = IPDigit[j];
//			}
//			if(i == sizeof(IP_ADDR)-1)
//				break;
//			LCDText[LCDPos++] = '.';
//		#else
//			if(i == sizeof(IP_ADDR)-1)
//				break;
//		#endif
//
//	}
//
//	#ifdef USE_LCD
//		if(LCDPos < 32u)
//			LCDText[LCDPos] = 0;
//		LCDUpdate();
//	#endif
//}



/****************************************************************************
  Function:
    static void InitializeBoard(void)

  Description:
    This routine initializes the hardware.  It is a generic initialization
    routine for many of the Microchip development boards, using definitions
    in HardwareProfile.h to determine specific initialization.

  Precondition:
    None

  Parameters:
    None - None

  Returns:
    None

  Remarks:
    None
  ***************************************************************************/
static void InitializeBoard(void)
{	

	BUTTON0_TRIS=1;
	//   1   
	//  
	LED0_TRIS=0;
	LED0_IO=0;
	
	// 
	ADCON1=0xff;
	CMCON=0xff;
	CCP1CON=0x00;
	CCP2CON=0x00;

	//OSCCON=0x74; //   8 
	//OSCTUNE=0x40; //  PLL+INTOSC   8*4=32 
	//    
	//while(!OSCCONbits.IOFS) continue;

	// SPI(    enc28j60
 	// 
	
	//SSPSTAT=0; // CKE=0
	//SSPCON1=0x20; //  SPI

	// Enable Interrupts
	RCONbits.IPEN = 1;		// Enable interrupt priorities
    INTCONbits.GIEH = 1;
    INTCONbits.GIEL = 1;

}

/*********************************************************************
 * Function:        void InitAppConfig(void)
 *
 * PreCondition:    MPFSInit() is already called.
 *
 * Input:           None
 *
 * Output:          Write/Read non-volatile config variables.
 *
 * Side Effects:    None
 *
 * Overview:        None
 *
 * Note:            None
 ********************************************************************/
// MAC Address Serialization using a MPLAB PM3 Programmer and 
// Serialized Quick Turn Programming (SQTP). 
// The advantage of using SQTP for programming the MAC Address is it
// allows you to auto-increment the MAC address without recompiling 
// the code for each unit.  To use SQTP, the MAC address must be fixed
// at a specific location in program memory.  Uncomment these two pragmas
// that locate the MAC address at 0x1FFF0.  Syntax below is for MPLAB C 
// Compiler for PIC18 MCUs. Syntax will vary for other compilers.
//#pragma romdata MACROM=0x1FFF0
static ROM BYTE SerializedMACAddress[6] = {MY_DEFAULT_MAC_BYTE1, MY_DEFAULT_MAC_BYTE2, MY_DEFAULT_MAC_BYTE3, MY_DEFAULT_MAC_BYTE4, MY_DEFAULT_MAC_BYTE5, MY_DEFAULT_MAC_BYTE6};
//#pragma romdata

static void InitAppConfig(void)
{
	AppConfig.Flags.bIsDHCPEnabled = TRUE;
	AppConfig.Flags.bInConfigMode = TRUE;
	memcpypgm2ram((void*)&AppConfig.MyMACAddr, (far ROM void*)SerializedMACAddress, sizeof(AppConfig.MyMACAddr));
//	{
//		_prog_addressT MACAddressAddress;
//		MACAddressAddress.next = 0x157F8;
//		_memcpy_p2d24((char*)&AppConfig.MyMACAddr, MACAddressAddress, sizeof(AppConfig.MyMACAddr));
//	}
	AppConfig.MyIPAddr.Val = MY_DEFAULT_IP_ADDR_BYTE1 | MY_DEFAULT_IP_ADDR_BYTE2<<8ul | MY_DEFAULT_IP_ADDR_BYTE3<<16ul | MY_DEFAULT_IP_ADDR_BYTE4<<24ul;
	AppConfig.DefaultIPAddr.Val = AppConfig.MyIPAddr.Val;
	AppConfig.MyMask.Val = MY_DEFAULT_MASK_BYTE1 | MY_DEFAULT_MASK_BYTE2<<8ul | MY_DEFAULT_MASK_BYTE3<<16ul | MY_DEFAULT_MASK_BYTE4<<24ul;
	AppConfig.DefaultMask.Val = AppConfig.MyMask.Val;
	AppConfig.MyGateway.Val = MY_DEFAULT_GATE_BYTE1 | MY_DEFAULT_GATE_BYTE2<<8ul | MY_DEFAULT_GATE_BYTE3<<16ul | MY_DEFAULT_GATE_BYTE4<<24ul;
	AppConfig.PrimaryDNSServer.Val = MY_DEFAULT_PRIMARY_DNS_BYTE1 | MY_DEFAULT_PRIMARY_DNS_BYTE2<<8ul  | MY_DEFAULT_PRIMARY_DNS_BYTE3<<16ul  | MY_DEFAULT_PRIMARY_DNS_BYTE4<<24ul;
	AppConfig.SecondaryDNSServer.Val = MY_DEFAULT_SECONDARY_DNS_BYTE1 | MY_DEFAULT_SECONDARY_DNS_BYTE2<<8ul  | MY_DEFAULT_SECONDARY_DNS_BYTE3<<16ul  | MY_DEFAULT_SECONDARY_DNS_BYTE4<<24ul;


	

	// Load the default NetBIOS Host Name
	memcpypgm2ram(AppConfig.NetBIOSName, (far ROM void*)MY_DEFAULT_HOST_NAME, 16);
	FormatNetBIOSName(AppConfig.NetBIOSName);

	
}

